Class: Google::Apis::PlayintegrityV1::PcAccountDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/playintegrity_v1/classes.rb,
lib/google/apis/playintegrity_v1/representations.rb,
lib/google/apis/playintegrity_v1/representations.rb

Overview

Contains the account information such as the licensing status for the user in the scope.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PcAccountDetails

Returns a new instance of PcAccountDetails.



345
346
347
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_licensing_verdictString

Required. Details about the licensing status of the user for the app in the scope. Corresponds to the JSON property appLicensingVerdict

Returns:

  • (String)


343
344
345
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 343

def app_licensing_verdict
  @app_licensing_verdict
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



350
351
352
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 350

def update!(**args)
  @app_licensing_verdict = args[:app_licensing_verdict] if args.key?(:app_licensing_verdict)
end