Class: Google::Apis::PlayintegrityV1::PcTestingDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/playintegrity_v1/classes.rb,
lib/google/apis/playintegrity_v1/representations.rb,
lib/google/apis/playintegrity_v1/representations.rb

Overview

Contains additional information generated for testing responses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PcTestingDetails

Returns a new instance of PcTestingDetails.



417
418
419
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_testing_responseBoolean Also known as: is_testing_response?

Indicates that the information contained in this payload is a testing response that is statically overridden for a tester. Corresponds to the JSON property isTestingResponse

Returns:

  • (Boolean)


414
415
416
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 414

def is_testing_response
  @is_testing_response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



422
423
424
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 422

def update!(**args)
  @is_testing_response = args[:is_testing_response] if args.key?(:is_testing_response)
end