Class: Google::Apis::PlayintegrityV1::WriteDates

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/playintegrity_v1/classes.rb,
lib/google/apis/playintegrity_v1/representations.rb,
lib/google/apis/playintegrity_v1/representations.rb

Overview

Contains the recall bits write dates.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WriteDates

Returns a new instance of WriteDates.



654
655
656
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#yyyymm_firstFixnum

Optional. Write time in YYYYMM format (in UTC, e.g. 202402) for the first bit. Note that this value won't be set if the first bit is false. Corresponds to the JSON property yyyymmFirst

Returns:

  • (Fixnum)


640
641
642
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 640

def yyyymm_first
  @yyyymm_first
end

#yyyymm_secondFixnum

Optional. Write time in YYYYMM format (in UTC, e.g. 202402) for the second bit. Note that this value won't be set if the second bit is false. Corresponds to the JSON property yyyymmSecond

Returns:

  • (Fixnum)


646
647
648
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 646

def yyyymm_second
  @yyyymm_second
end

#yyyymm_thirdFixnum

Optional. Write time in YYYYMM format (in UTC, e.g. 202402) for the third bit. Note that this value won't be set if the third bit is false. Corresponds to the JSON property yyyymmThird

Returns:

  • (Fixnum)


652
653
654
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 652

def yyyymm_third
  @yyyymm_third
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



659
660
661
662
663
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 659

def update!(**args)
  @yyyymm_first = args[:yyyymm_first] if args.key?(:yyyymm_first)
  @yyyymm_second = args[:yyyymm_second] if args.key?(:yyyymm_second)
  @yyyymm_third = args[:yyyymm_third] if args.key?(:yyyymm_third)
end