Class: Google::Apis::PlayintegrityV1::AppAccessRiskVerdict
- Inherits:
-
Object
- Object
- Google::Apis::PlayintegrityV1::AppAccessRiskVerdict
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/playintegrity_v1/classes.rb,
lib/google/apis/playintegrity_v1/representations.rb,
lib/google/apis/playintegrity_v1/representations.rb
Overview
Contains signals about others apps on the device which could be used to access or control the requesting app.
Instance Attribute Summary collapse
-
#apps_detected ⇒ Array<String>
List of detected app types signalled for App Access Risk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AppAccessRiskVerdict
constructor
A new instance of AppAccessRiskVerdict.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AppAccessRiskVerdict
Returns a new instance of AppAccessRiskVerdict.
83 84 85 |
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 83 def initialize(**args) update!(**args) end |
Instance Attribute Details
#apps_detected ⇒ Array<String>
List of detected app types signalled for App Access Risk.
Corresponds to the JSON property appsDetected
81 82 83 |
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 81 def apps_detected @apps_detected end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
88 89 90 |
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 88 def update!(**args) @apps_detected = args[:apps_detected] if args.key?(:apps_detected) end |