Class: Google::Apis::PlayintegrityV1::DeviceIntegrity
- Inherits:
-
Object
- Object
- Google::Apis::PlayintegrityV1::DeviceIntegrity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/playintegrity_v1/classes.rb,
lib/google/apis/playintegrity_v1/representations.rb,
lib/google/apis/playintegrity_v1/representations.rb
Overview
Contains the device attestation information.
Instance Attribute Summary collapse
-
#device_attributes ⇒ Google::Apis::PlayintegrityV1::DeviceAttributes
Contains information about the device for which the integrity token was generated, e.g.
-
#device_recall ⇒ Google::Apis::PlayintegrityV1::DeviceRecall
Contains the recall bits per device set by the developer.
-
#device_recognition_verdict ⇒ Array<String>
Details about the integrity of the device the app is running on.
-
#legacy_device_recognition_verdict ⇒ Array<String>
Contains legacy details about the integrity of the device the app is running on.
-
#recent_device_activity ⇒ Google::Apis::PlayintegrityV1::RecentDeviceActivity
Recent device activity can help developers identify devices that have exhibited hyperactive attestation activity, which could be a sign of an attack or token farming.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeviceIntegrity
constructor
A new instance of DeviceIntegrity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeviceIntegrity
Returns a new instance of DeviceIntegrity.
268 269 270 |
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 268 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_attributes ⇒ Google::Apis::PlayintegrityV1::DeviceAttributes
Contains information about the device for which the integrity token was
generated, e.g. Android SDK version.
Corresponds to the JSON property deviceAttributes
241 242 243 |
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 241 def device_attributes @device_attributes end |
#device_recall ⇒ Google::Apis::PlayintegrityV1::DeviceRecall
Contains the recall bits per device set by the developer.
Corresponds to the JSON property deviceRecall
246 247 248 |
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 246 def device_recall @device_recall end |
#device_recognition_verdict ⇒ Array<String>
Details about the integrity of the device the app is running on.
Corresponds to the JSON property deviceRecognitionVerdict
251 252 253 |
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 251 def device_recognition_verdict @device_recognition_verdict end |
#legacy_device_recognition_verdict ⇒ Array<String>
Contains legacy details about the integrity of the device the app is running
on. Only for devices with Android version T or higher and only for apps opted
in to the new verdicts. Only available during the transition period to the new
verdicts system and will be removed afterwards.
Corresponds to the JSON property legacyDeviceRecognitionVerdict
259 260 261 |
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 259 def legacy_device_recognition_verdict @legacy_device_recognition_verdict end |
#recent_device_activity ⇒ Google::Apis::PlayintegrityV1::RecentDeviceActivity
Recent device activity can help developers identify devices that have
exhibited hyperactive attestation activity, which could be a sign of an attack
or token farming.
Corresponds to the JSON property recentDeviceActivity
266 267 268 |
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 266 def recent_device_activity @recent_device_activity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
273 274 275 276 277 278 279 |
# File 'lib/google/apis/playintegrity_v1/classes.rb', line 273 def update!(**args) @device_attributes = args[:device_attributes] if args.key?(:device_attributes) @device_recall = args[:device_recall] if args.key?(:device_recall) @device_recognition_verdict = args[:device_recognition_verdict] if args.key?(:device_recognition_verdict) @legacy_device_recognition_verdict = args[:legacy_device_recognition_verdict] if args.key?(:legacy_device_recognition_verdict) @recent_device_activity = args[:recent_device_activity] if args.key?(:recent_device_activity) end |